@@ -18,9 +18,9 @@ class Stock:
     ticker : str
         ticker of a stock; country code needs to be append after a dot for not
         Polish stocks, e.g, 'AAPL.US'
-    ohlc : pandas.DataFrame
+    _ohlc : pandas.DataFrame
         DataFrame with OHLC prices (open-high-low-close), and volume
-    fundamentals : dict
+    _fundamentals : dict
         dictionary with available fundamental information
     """
 
