@@ -1,7 +1,5 @@
-from . import DATA_DIR
+from . import get_dwl_storage_status, get_dwl_storage_dir
 from datetime import datetime
-import pandas as pd
-import requests
 import os
 import csv
 from .scrapers import scrap_summary_table
@@ -22,9 +20,9 @@ class Fundamentals(dict):
         """
 
         update_required = True  # assuming that update will be required
-        file_path = os.path.join(DATA_DIR, f'{self.ticker}_indicators.csv')
+        file_path = os.path.join(get_dwl_storage_dir(), f'{self.ticker}_indicators.csv')
 
-        if os.path.exists(file_path):
+        if get_dwl_storage_status() and os.path.exists(file_path):
             timestamp_now = datetime.timestamp(datetime.now())
             timestamp_up = os.path.getatime(file_path)  # CSV file modification time
 
@@ -45,10 +43,11 @@ class Fundamentals(dict):
         if update_required:
             # data older than 24 hours - update
             self.update(scrap_summary_table(self.ticker))
-            with open(file_path, 'w') as f:
-                writer = csv.DictWriter(f, self.keys())
-                writer.writeheader()
-                writer.writerow(self)
+            if get_dwl_storage_status():
+                with open(file_path, 'w') as f:
+                    writer = csv.DictWriter(f, self.keys())
+                    writer.writeheader()
+                    writer.writerow(self)
 
         if bool(self) is False:
             # no fundamental data (None or empty dict)
